aboutsummaryrefslogtreecommitdiff
path: root/spss.server/src/at/gv/egovernment/moa/spss/api/common/Content.java
diff options
context:
space:
mode:
Diffstat (limited to 'spss.server/src/at/gv/egovernment/moa/spss/api/common/Content.java')
-rw-r--r--spss.server/src/at/gv/egovernment/moa/spss/api/common/Content.java14
1 files changed, 12 insertions, 2 deletions
diff --git a/spss.server/src/at/gv/egovernment/moa/spss/api/common/Content.java b/spss.server/src/at/gv/egovernment/moa/spss/api/common/Content.java
index 173e9d395..0777c3d65 100644
--- a/spss.server/src/at/gv/egovernment/moa/spss/api/common/Content.java
+++ b/spss.server/src/at/gv/egovernment/moa/spss/api/common/Content.java
@@ -5,29 +5,39 @@ package at.gv.egovernment.moa.spss.api.common;
*
* @author Patrick Peck
* @author Stephan Grill
+ * @author Gregor Karlinger
* @version $Id$
*/
public interface Content {
+
/**
* Indicates that this object contains a URI reference to some content.
*/
public static final int REFERENCE_CONTENT = 0;
+
/**
* Indicates that this object contains binary content.
*/
public static final int BINARY_CONTENT = 1;
+
/**
* Indicates that this object contains XML content.
*/
public static final int XML_CONTENT = 2;
+
+ /**
+ * Indicates that this object contains a location reference content.
+ */
+ public static final int LOCREF_CONTENT = 3;
/**
* Gets the type of content contained in this object.
*
* @return The type of content, either <code>BINARY_CONTENT</code> or
* <code>XML_CONTENT</code>
*/
public int getContentType();
+
/**
* Gets the reference to the content data (a URI).
*
@@ -5,29 +5,39 @@ package at.gv.egovernment.moa.spss.api.common;
* Gets the type of content contained in this object.
*
- * @return The type of content, either <code>BINARY_CONTENT</code> or
- * <code>XML_CONTENT</code>
+ * @return The type of content, one of <code>BINARY_CONTENT</code>, <code>XML_CONTENT</code>, <code>
+ * REFERENCE_CONTENT</code> or <code>LOCREF_CONTENT</code>.
*/
public int getContentType();